@@ -1,4 +1,4 @@
-/* $Id: board.cc,v 1.62 2002/02/13 03:53:56 bergo Exp $ */
+/* $Id: board.cc,v 1.65 2002/04/07 04:49:21 bergo Exp $ */
 
 /*
 
@@ -30,6 +30,7 @@
 #include "board.h"
 #include "chess.h"
 #include "global.h"
+#include "text.h"
 
 #include "mainwindow.h"
 
@@ -145,6 +146,8 @@ gboolean bareboard_expose(GtkWidget *widget,GdkEventExpose *ee,
 
 Board::Board(bool withbugpane=false) : WidgetProxy() {
   int i;
+  GtkWidget *tnb=0, *tl1, *tl2;
+  Text *text=0;
 
   global.debug("Board","Board");
 
@@ -207,7 +210,28 @@ Board::Board(bool withbugpane=false) : WidgetProxy() {
     createBugPane();
 
   gtk_paned_pack1(GTK_PANED(widget),yidget,TRUE,FALSE);
-  gtk_paned_pack2(GTK_PANED(widget),bugpane,TRUE,TRUE);  
+
+  if (withbugpane) {
+    tnb=gtk_notebook_new();
+    
+    tl1=gtk_label_new("Console");
+    tl2=gtk_label_new("Bughouse");
+    
+    text=new Text();
+
+    gtk_notebook_append_page(GTK_NOTEBOOK(tnb), text->widget, tl1);
+    gtk_notebook_append_page(GTK_NOTEBOOK(tnb), bugpane, tl2);
+    gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tnb), GTK_POS_RIGHT);
+
+    global.outputset->addTarget(text);
+    gtk_paned_pack2(GTK_PANED(widget), tnb, TRUE,TRUE);
+
+  } else {
+
+    gtk_paned_pack2(GTK_PANED(widget),bugpane,TRUE,TRUE);
+
+  }
+
   gtk_paned_set_position(GTK_PANED(widget),7000);
   gtk_paned_set_gutter_size(GTK_PANED(widget),withbugpane?8:0);
   gtk_paned_set_handle_size(GTK_PANED(widget),withbugpane?8:0);
@@ -227,6 +251,14 @@ Board::Board(bool withbugpane=false) : WidgetProxy() {
 		      (gpointer) this);
 
   gtk_widget_show(yidget);
+
+  if (withbugpane) {
+    text->show();
+    gtk_widget_show(tl1);
+    gtk_widget_show(tl2);
+    gtk_widget_show(tnb);
+  }
+
   gtk_widget_show(bugpane);
   gtk_widget_show(widget);
 }
@@ -549,11 +581,15 @@ void Board::renderClock() {
   GdkGC *gc;
   int i,j,k,sq,bh,ch,th;
   char z[64];
-  bool ef;
+  bool ef, lowtime=false;
 
   if (!clock_ch)
     return;
 
+  if (mygame)
+    if (mygame->AmPlaying)
+      lowtime=clock.lowTimeWarning(mygame->MyColor);
+
   sq=sqside;
 
   gc=gdk_gc_new(clkbar);
@@ -583,6 +619,7 @@ void Board::renderClock() {
 
   C.setColor(0xffffff);
   if (clock.getActive()>0) {
+    if (lowtime) C.setColor(0xff8080);
     C.drawRect(15, i - (ch+2), 200-30, bh+4, true);
     C.setColor(0);
   }
@@ -595,6 +632,7 @@ void Board::renderClock() {
 
   C.setColor(0xffffff);
   if (clock.getActive()<0) {
+    if (lowtime) C.setColor(0xff8080);
     C.drawRect(15, i - (ch+2), 200-30, bh+4, true);
     C.setColor(0);
   }
