@@ -1,4 +1,4 @@
-/* $Id: board.h,v 1.32 2001/10/14 17:36:26 bergo Exp $ */
+/* $Id: board.h,v 1.34 2002/02/13 03:53:56 bergo Exp $ */
 
 /*
 
@@ -43,11 +43,12 @@ class ChessGame;
 
 class DropSource {
  public:
-  DropSource(piece p, int x1,int y1,int w,int h);
+  DropSource(piece p, int x1,int y1,int w,int h, bool d=true);
   bool hit(int x,int y);
 
   int X,Y,X2,Y2;
   piece P;
+  bool dragged;
 };
 
 class TargetManager {
@@ -121,6 +122,7 @@ class Board : public WidgetProxy,
   void  reset();
   
   void  setGame(ChessGame *game);
+  ChessGame *getGame();
   void  reloadFonts();
 
   void freeze();
@@ -150,6 +152,7 @@ class Board : public WidgetProxy,
   void addBugText(char *text);
 
   bool FreeMove; // editing positions, examining games
+  bool EditMode; // explicit edit mode (with pieces to drop and additional commands)
  
   BareBoard *bugboard;
 
@@ -186,6 +189,7 @@ class Board : public WidgetProxy,
 
   ChessGame *mygame;
   ChessClock clock;
+  LayoutBox C;
 
   int hilite_ch, clock_ch;
 
@@ -237,8 +241,6 @@ class Board : public WidgetProxy,
 
   bool effectiveFlip();
 
-  GdkFont *loadFallbackFont(int i);
-
   friend gboolean board_animate(gpointer data);
   friend gboolean vec_board_animate(gpointer data);
 
@@ -270,5 +272,10 @@ class Board : public WidgetProxy,
   friend void board_ptell(GtkWidget *b,gpointer data);
 };
 
+class EditBoard : public Board {
+ public:
+  EditBoard(ChessGame *cg);
+};
+
 #endif
 
