@@ -1,4 +1,4 @@
-/* $Id: chess.cc,v 1.49 2002/02/13 03:53:56 bergo Exp $ */
+/* $Id: chess.cc,v 1.51 2002/03/29 14:27:25 bergo Exp $ */
 
 /*
 
@@ -65,6 +65,10 @@ ChessGame::ChessGame() {
   Loaded=true;
   PGNSource[0]=0;
   SourceOffset=0;
+
+  source=GS_Other;
+  source_data="n/a";
+  AmPlaying=false;
 }
 
 ChessGame::ChessGame(int _number,int _tyme,int _inc, int _rated,
@@ -90,6 +94,10 @@ ChessGame::ChessGame(int _number,int _tyme,int _inc, int _rated,
   Loaded=true;
   PGNSource[0]=0;
   SourceOffset=0;
+
+  source=GS_Other;
+  source_data="n/a";
+  AmPlaying=false;
 }
 
 ChessGame::ChessGame(ChessGame *src) {
@@ -128,6 +136,10 @@ ChessGame::ChessGame(ChessGame *src) {
   if (moves.empty())
     moves.push_back(new Position());
   if (!cset) { cursor = moves.end();  cursor--; }
+
+  source=src->source;
+  source_data=src->source_data;
+  AmPlaying=src->AmPlaying;
 }
 
 ChessGame::~ChessGame() {
@@ -826,6 +838,8 @@ bool ChessGame::ParsePgnGame(FILE *f,
     game = new ChessGame();
     game->Variant = v;
     game->GameNumber = gameid;
+    game->source = GS_PGN_File;
+    game->source_data = filename;
 
     if (indexonly) {
       game->Loaded=false;
