@@ -1,4 +1,4 @@
-/* $Id: dlg_gamelist.cc,v 1.17 2002/03/17 04:53:36 bergo Exp $ */
+/* $Id: dlg_gamelist.cc,v 1.18 2002/03/29 05:23:37 bergo Exp $ */
 
 /*
 
@@ -30,6 +30,7 @@
 #include "global.h"
 #include "chess.h"
 #include "dlg_gamelist.h"
+#include "tstring.h"
 
 #include "icon-games.xpm"
 #include "icon-ads.xpm"
@@ -43,6 +44,13 @@
 #include "goc_discard.xpm"
 #include "goc_edit.xpm"
 
+#include "treeics.xpm"
+#include "treepgn.xpm"
+#include "treeeng.xpm"
+#include "treeoth.xpm"
+#include "treepgnf.xpm"
+#include "treegam.xpm"
+
 GameListDialog::GameListDialog(GameListListener *someone) {
   GtkWidget *sw,*v,*bh;
   GtkStyle *style;
@@ -224,12 +232,38 @@ StockListDialog::StockListDialog(StockListListener *someone) {
   canclose=1;
 
   widget=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_default_size(GTK_WINDOW(widget),600,400);
+  gtk_window_set_default_size(GTK_WINDOW(widget),650,400);
   gtk_window_set_title(GTK_WINDOW(widget),"Local Game List");
   gtk_window_set_position(GTK_WINDOW(widget),GTK_WIN_POS_CENTER);
   gtk_container_set_border_width(GTK_CONTAINER(widget),4);
   gtk_widget_realize(widget);
 
+  style=gtk_widget_get_style(widget);
+  icons[0] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[0],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treeics_xpm);
+
+  icons[1] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[1],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treepgn_xpm);
+
+  icons[2] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[2],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treeeng_xpm);
+
+  icons[3] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[3],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treeoth_xpm);
+
+  icons[4] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[4],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treepgnf_xpm);
+
+  icons[5] = gdk_pixmap_create_from_xpm_d (widget->window, &masks[5],
+					   &style->bg[GTK_STATE_NORMAL],
+					   (gchar **) treegam_xpm);
+
+
   h=gtk_hbox_new(FALSE,0);
   gtk_container_add(GTK_CONTAINER(widget),h);
 
@@ -273,8 +307,9 @@ StockListDialog::StockListDialog(StockListListener *someone) {
   else
     cerr << "<StockListDialog::StockListDialog> Warning: couldn't load fixed font, this dialog's content will look awful.\n\n";
   
-  // number displayed white black variant result
-  clist=gtk_clist_new(6);
+  // number(tree) displayed white black variant result
+
+  clist=gtk_ctree_new(7,0);
   gtk_clist_set_shadow_type(GTK_CLIST(clist),GTK_SHADOW_IN);
   gtk_clist_set_selection_mode(GTK_CLIST(clist),GTK_SELECTION_SINGLE);
   gtk_clist_set_column_title(GTK_CLIST(clist),0,"Game #");
@@ -283,6 +318,10 @@ StockListDialog::StockListDialog(StockListListener *someone) {
   gtk_clist_set_column_title(GTK_CLIST(clist),3,"Black");
   gtk_clist_set_column_title(GTK_CLIST(clist),4,"Variant");
   gtk_clist_set_column_title(GTK_CLIST(clist),5,"Result");
+
+  gtk_clist_set_column_title(GTK_CLIST(clist),6,"ctree is buggy it seems");
+  gtk_clist_set_column_visibility(GTK_CLIST(clist),6,FALSE);
+
   gtk_clist_column_titles_passive(GTK_CLIST(clist));
   gtk_clist_column_titles_show(GTK_CLIST(clist));
 
@@ -297,6 +336,8 @@ StockListDialog::StockListDialog(StockListListener *someone) {
     gtk_clist_set_column_min_width(GTK_CLIST(clist),i,64);
   gtk_clist_columns_autosize(GTK_CLIST(clist));
 
+  // ----------------------------------
+
   for(i=0;i<7;i++)
     gtk_widget_show(b[i]);
 
@@ -335,9 +376,10 @@ StockListDialog::StockListDialog(StockListListener *someone) {
 		     GTK_SIGNAL_FUNC(stocklist_editpgn),(gpointer)this);
   gtk_signal_connect(GTK_OBJECT(b[4]),"clicked",
 		     GTK_SIGNAL_FUNC(stocklist_savepgn),(gpointer)this);
-  gtk_signal_connect(GTK_OBJECT(clist),"select_row",
+
+  gtk_signal_connect(GTK_OBJECT(clist),"tree_select_row",
 		     GTK_SIGNAL_FUNC(stocklist_select),(gpointer)this);
-  gtk_signal_connect(GTK_OBJECT(clist),"unselect_row",
+  gtk_signal_connect(GTK_OBJECT(clist),"tree_unselect_row",
 		     GTK_SIGNAL_FUNC(stocklist_unselect),(gpointer)this);
 
   refresh();
@@ -346,18 +388,41 @@ StockListDialog::StockListDialog(StockListListener *someone) {
 void StockListDialog::refresh() {
   list<ChessGame *>::iterator gli;
   char x[16],y[8],z[64],a[64],b[32],c[16];
-  char *zp[6];
+  char *zp[7];
+  int i,j;
+
+  char ka[256], kb[256], *kp;
+  int kids[4];
+
+  vector<GtkCTreeNode *> filenodes;
+  vector<string> filenames;
+  vector<int>    count;
+
+  GtkCTreeNode *myfile;
+  TString T(512);
+
+  static char *e="e";
+  static char *es="es";
 
   SelectedRow=-1;
   gtk_clist_freeze(GTK_CLIST(clist));
   gtk_clist_clear(GTK_CLIST(clist));
 
+  // add toplevel nodes
+  for(i=0;i<4;i++)
+    toplevel[i]=gtk_ctree_insert_node(GTK_CTREE(clist),0,0,
+				      0,2, icons[i],masks[i], icons[i],masks[i], 
+				      FALSE, TRUE);
+
+  kids[0]=kids[1]=kids[2]=kids[3]=0;
+
   zp[0]=x;
   zp[1]=y;
   zp[2]=z;
   zp[3]=a;
   zp[4]=b;
   zp[5]=c;
+  zp[6]=x;
 
   for(gli=global.GameList.begin();gli!=global.GameList.end();gli++) {
     sprintf(x,"%d",(*gli)->GameNumber);
@@ -380,9 +445,80 @@ void StockListDialog::refresh() {
       case UNDEF:     strcpy(c,"*"); break;
       }
     }
-    gtk_clist_append(GTK_CLIST(clist),zp);
+
+    if ( (*gli)->source == GS_PGN_File ) {
+      j=-1;
+      for(i=0;i<filenames.size();i++) {
+	if ( filenames[i] == (*gli)->source_data ) {
+	  count[i]++;
+	  j=i; break;
+	}
+      }
+
+      if (j<0) {
+	myfile=gtk_ctree_insert_node(GTK_CTREE(clist), toplevel[1], 0,
+				     0, 2, icons[4],masks[4], 
+				     icons[4],masks[4], FALSE, TRUE);
+	filenames.push_back( (*gli)->source_data );
+	filenodes.push_back( myfile );
+	count.push_back(1);
+	j = filenames.size() - 1;
+      }
+
+      gtk_ctree_insert_node(GTK_CTREE(clist), filenodes[j], 0,
+			    zp, 2, icons[5],masks[5], icons[5],masks[5], TRUE, TRUE);
+      kids[1]++;
+    } else {
+      switch( (*gli)->source ) {
+      case GS_ICS: j=0; break;
+      case GS_Engine: j=2; break;
+      case GS_Other: j=3; break;
+      default: j=3;
+      }
+
+      gtk_ctree_insert_node(GTK_CTREE(clist), toplevel[j], 0,
+			    zp, 2, icons[5],masks[5], icons[5],masks[5], TRUE, TRUE);
+      kids[j]++;
+    }    
+
   }
 
+  for(i=0;i<count.size();i++) {
+    strncpy(ka, filenames[i].c_str(), 256);
+    ka[255]=0;
+    T.set( ka );
+
+    do {
+      kp=T.token("/\n\r");
+      if (kp) { strncpy(ka, kp, 256); ka[255]=0; }
+    } while(kp);
+
+    snprintf(kb,256,"%s (%d gam%s)", ka, count[i], count[i]==1?e:es);
+    kb[255]=0;
+      
+    gtk_ctree_node_set_pixtext(GTK_CTREE(clist) , filenodes[i], 0, kb,
+			       4, icons[4], masks[4]);
+  }
+
+  for(i=0;i<4;i++)
+    gtk_ctree_node_set_text(GTK_CTREE(clist), toplevel[i], 6, "gtk-is-buggy");
+
+  sprintf(kb,"From ICS (%d gam%s)", kids[0], kids[0]==1?e:es);
+  gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[0], 0, kb, 
+			     4, icons[0],masks[0]);
+
+  sprintf(kb,"From PGN Files (%d gam%s)", kids[1], kids[1]==1?e:es);
+  gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[1], 0, kb,
+			     4, icons[1], masks[1]);
+
+  sprintf(kb,"From Engines (%d gam%s)", kids[2], kids[2]==1?e:es);
+  gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[2], 0, kb,
+			     4, icons[2], masks[2]);
+
+  sprintf(kb,"From Elsewhere (%d gam%s)", kids[3], kids[3]==1?e:es);
+  gtk_ctree_node_set_pixtext(GTK_CTREE(clist), toplevel[3], 0, kb,
+			     4, icons[3], masks[3]);
+
   gtk_clist_columns_autosize(GTK_CLIST(clist));
   gtk_clist_thaw(GTK_CLIST(clist));
   calcEnable();
@@ -393,7 +529,7 @@ void StockListDialog::open() {
   ChessGame *cg;
   char tab[32];
 
-  cg=global.getGame(getSelCol0());
+  cg=global.getGame(SelectedRow);
   if (!cg)
     return;
 
@@ -458,7 +594,7 @@ void StockListDialog::trash() {
   Board *b;
   list<ChessGame *>::iterator gli;
 
-  cg=global.getGame(getSelCol0());
+  cg=global.getGame(SelectedRow);
   if (!cg)
     return;
 
@@ -487,14 +623,6 @@ void StockListDialog::trash() {
   refresh();
 }
 
-int StockListDialog::getSelCol0() {
-  char *z;
-  int gn;
-  gtk_clist_get_text(GTK_CLIST(clist),SelectedRow,0,&z);
-  gn=atoi(z);
-  return gn;
-}
-
 void StockListDialog::calcEnable() {
   ChessGame *cg;
 
@@ -507,7 +635,7 @@ void StockListDialog::calcEnable() {
     return;
   }
 
-  cg=global.getGame(getSelCol0());
+  cg=global.getGame(SelectedRow);
   if (!cg)
     goto oops;
 
@@ -549,7 +677,7 @@ stocklist_savepgn (GtkWidget * w, gpointer data)
   fd=new FileDialog("Save as PGN");
   
   if (fd->run()) {
-    cg=global.getGame(me->getSelCol0());
+    cg=global.getGame(me->SelectedRow);
     if (cg)
       cg->savePGN(fd->FileName);
   }
@@ -580,7 +708,7 @@ stocklist_editpgn (GtkWidget * w, gpointer data)
   StockListDialog *me;
   ChessGame *cg;
   me=(StockListDialog *)data;
-  cg=global.getGame(me->getSelCol0());
+  cg=global.getGame(me->SelectedRow);
   if (!cg)
     return;
   (new PGNEditInfoDialog(cg))->show();
@@ -611,22 +739,38 @@ stocklist_destroy (GtkWidget * widget, gpointer data)
     me->owner->stockListClosed();
 }
 
+// the gtk documentation has a wrong declaration of this,
+// only figured out after looking at the code of the Balsa
+// mail client
+
 void
-stocklist_select  (GtkCList *cl, gint row, gint column, GdkEventButton *eb,
+stocklist_select  (GtkCTree *cl, GtkCTreeNode *node, gint column,
 		   gpointer data)
 {
   StockListDialog *me;
+  char *p;
+
   me=(StockListDialog *)data;
-  me->SelectedRow=row;
-  me->calcEnable();
+
+  // getting column 0 either crashes or returns garbage, so
+  // I duplicated it in an invisible column
+  gtk_ctree_node_get_text(cl, 
+			  node,
+			  6, &p);
+  if (p[0] != 'g') {
+    me->SelectedRow=atoi(p);
+    if (me->SelectedRow == 0) me->SelectedRow=-1;
+    me->calcEnable();
+  }
 }
 
 void
-stocklist_unselect  (GtkCList *cl, gint row, gint column, GdkEventButton *eb,
-		     gpointer data)
+stocklist_unselect (GtkCTree *cl, GtkCTreeNode *node, gint column,
+		    gpointer data)
 {
   StockListDialog *me;
   int i;
+
   me=(StockListDialog *)data;
   me->SelectedRow=-1;
   for(i=1;i<3;i++)
