@@ -1,4 +1,4 @@
-/* $Id: dlg_prefs.cc,v 1.18 2002/03/17 04:53:36 bergo Exp $ */
+/* $Id: dlg_prefs.cc,v 1.20 2002/04/08 00:44:50 bergo Exp $ */
 
 /*
 
@@ -47,11 +47,12 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   GtkWidget *fl, *fv, *ft, *fn[4], *fb[4], *frv;
 
   // -- ics
-  GtkWidget *icv, *icl, *ich1, *icl1, *ifr1, *ifr2, *ifv1, *ifv2;
+  GtkWidget *icv, *icl, *ict1, *icl1, *ifr1, *ifr2, *ifv1, *ifv2, *icl2, *icl3;
 
   // -- sound
   GtkWidget *sv,*sl,*zl,*zf,*zv,*zd,*zt,*ze,*zh;
-  static char *zcaption[]={"Opponent Moved","Draw Offered","Private Tell","ICS Challenge"};
+  static char *zcaption[]={"Opponent Moved","Draw Offered","Private Tell",
+			   "ICS Challenge","Time Running Out"};
   char **zp;
 
   // -- autosave
@@ -62,7 +63,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   int i;
   char z[64];
 
-  for(i=0;i<4;i++)
+  for(i=0;i< N_SOUND_EVENTS;i++)
     sndcopy[i]=global.sndevents[i];
 
   gtk_window_set_default_size(GTK_WINDOW(widget),450,300);
@@ -186,18 +187,37 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   coct=gtk_check_button_new_with_label("Show channel tells on console too (when above option is active)");
   gtk_box_pack_start(GTK_BOX(ifv2),coct,FALSE,FALSE,4);
 
-  ich1=gtk_hbox_new(FALSE,4);
+  wget=gtk_check_button_new_with_label("Retrieve ICS Channel Lists from eboard.sf.net");
+  gtk_box_pack_start(GTK_BOX(ifv2),wget,FALSE,FALSE,0);
+
+  ict1=gtk_table_new(2,3,FALSE);
+
   icl1=gtk_label_new("Scrollback limit (0 = unlimited) :");
   sbacke=gtk_entry_new();
   sprintf(z,"%d",global.ScrollBack);
   gtk_entry_set_text(GTK_ENTRY(sbacke),z);
-  gtk_box_pack_start(GTK_BOX(ich1),icl1,FALSE,FALSE,0);
-  gtk_box_pack_start(GTK_BOX(ich1),sbacke,FALSE,FALSE,4);
-  gtk_box_pack_start(GTK_BOX(icv),ich1,FALSE,FALSE,4);
 
-  gtk_widget_show(ich1);
+  gtk_table_attach_defaults(GTK_TABLE(ict1), icl1, 0,1, 0,1);
+  gtk_table_attach_defaults(GTK_TABLE(ict1), sbacke, 1,2, 0,1);
+
+  icl2=gtk_label_new("Warn when own clock is below: ");
+  lowtime=gtk_entry_new();
+  sprintf(z,"%d",global.LowTimeWarningLimit);
+  gtk_entry_set_text(GTK_ENTRY(lowtime),z);
+  icl3=gtk_label_new("seconds.");
+
+  gtk_table_attach_defaults(GTK_TABLE(ict1), icl2, 0,1, 1,2);
+  gtk_table_attach_defaults(GTK_TABLE(ict1), lowtime, 1,2, 1,2);
+  gtk_table_attach_defaults(GTK_TABLE(ict1), icl3, 2,3, 1,2);
+
+  gtk_box_pack_start(GTK_BOX(icv),ict1,FALSE,FALSE,4);
+
   gtk_widget_show(icl1);
   gtk_widget_show(sbacke);
+  gtk_widget_show(icl2);
+  gtk_widget_show(lowtime);
+  gtk_widget_show(icl3);
+  gtk_widget_show(ict1);
 
   gtk_widget_show(ifr1);
   gtk_widget_show(ifr2);
@@ -210,6 +230,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   gtk_widget_show(sgb);
   gtk_widget_show(chsb);
   gtk_widget_show(coct);
+  gtk_widget_show(wget);
   gtk_widget_show(hsb);
   gtk_widget_show(icv);
   
@@ -220,6 +241,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hsb), global.HideSeeks?1:0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chsb), global.SplitChannels?1:0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(coct), global.ChannelsToConsoleToo?1:0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wget), global.RetrieveChannelNames?1:0);
 
   // colors ========================================================================
 
@@ -366,7 +388,7 @@ PreferencesDialog::PreferencesDialog() : ModalDialog("Preferences") {
   gtk_clist_column_titles_hide(GTK_CLIST(zl));
   gtk_box_pack_start(GTK_BOX(zv),zl,TRUE,TRUE,4);
 
-  for(i=0;i<4;i++) {
+  for(i=0;i<N_SOUND_EVENTS;i++) {
     zp=&(zcaption[i]);
     gtk_clist_append(GTK_CLIST(zl),(gchar **) zp);
   }
@@ -557,6 +579,7 @@ void PreferencesDialog::Apply() {
   ApplyCheckBox(hsb, &global.HideSeeks, &changed, 0);
   ApplyCheckBox(chsb, &global.SplitChannels, &changed, 0);
   ApplyCheckBox(coct, &global.ChannelsToConsoleToo, &changed, 0);
+  ApplyCheckBox(wget, &global.RetrieveChannelNames, &changed, 0);
   ApplyCheckBox(asp, &global.AppendPlayed, &changed, 0);
   ApplyCheckBox(aso, &global.AppendObserved, &changed, 0);
 
@@ -592,7 +615,14 @@ void PreferencesDialog::Apply() {
     global.updateScrollBacks();
   }
 
-  for(i=0;i<4;i++)
+  p=gtk_entry_get_text(GTK_ENTRY(lowtime));
+  nval=atoi(p);
+  if (nval!=global.LowTimeWarningLimit) {
+    changed=1;
+    global.LowTimeWarningLimit=nval;
+  }
+
+  for(i=0;i<N_SOUND_EVENTS;i++)
     if (sndcopy[i] != global.sndevents[i]) {
       global.sndevents[i]=sndcopy[i];
       changed=1;
