@@ -1,4 +1,4 @@
-/* $Id: dlg_prefs.h,v 1.16 2002/03/17 04:53:36 bergo Exp $ */
+/* $Id: dlg_prefs.h,v 1.18 2002/04/08 00:44:50 bergo Exp $ */
 
 /*
 
@@ -26,6 +26,7 @@
 #ifndef EBOARD_PREFS
 #define EBOARD_PREFS
 
+#include "eboard.h"
 #include "sound.h"
 #include "widgetproxy.h"
 
@@ -41,9 +42,10 @@ class PreferencesDialog : public ModalDialog,
  private:
   GtkWidget *tabposb[4],*efont[4],*fontdlg,*plainb,
     *aapieceb, *showratb, *autologb, *sbacke, *snddesc, *sndb[2],
-    *asp, *aso, *afn, *sgb, *hsb, *chsb, *coct, *dhsb, *aqbar;
+    *asp, *aso, *afn, *sgb, *hsb, *chsb, *coct, *dhsb, *aqbar, *lowtime,
+    *wget;
   BoxedLabel *fm[4];
-  SoundEvent sndcopy[4];
+  SoundEvent sndcopy[N_SOUND_EVENTS];
   ColorButton *lsq, *dsq, *textcb[11];
   TextPreview *preview;
   int selected_sound_event;
