@@ -1,10 +1,10 @@
-/* $Id: eboard.h,v 1.23 2002/03/12 02:03:23 bergo Exp $ */
+/* $Id: eboard.h,v 1.24 2002/03/29 05:23:37 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -165,5 +165,14 @@ typedef enum {
   EF_InfoFont
 } EboardFont;
 
+typedef enum {
+  GS_PGN_File,
+  GS_ICS,
+  GS_Engine,
+  GS_Other=99
+} GameSource;
+
+#define N_SOUND_EVENTS 5
+
 #endif
 
