@@ -913,7 +913,10 @@ gtk_ftext_get_word (GtkFText * ftext, int x, int y, textentry ** ret_ent,
 
   while (!is_del (*str) && str != ent->str)
     str--;
-  word = str + 1;
+
+  word = str;
+  if (is_del(*str))
+    ++word;
 
   len = 0;
   str = word;
