@@ -1,4 +1,4 @@
-/* $Id: global.cc,v 1.48 2002/03/17 20:51:47 bergo Exp $ */
+/* $Id: global.cc,v 1.53 2002/04/08 00:44:50 bergo Exp $ */
 
 /*
 
@@ -52,6 +52,7 @@ Global global;
 Global::Global() {
   input=0;
   output=0;
+  outputset=0;
   network=0;
   status=0;
   protocol=0;
@@ -97,7 +98,7 @@ Global::Global() {
   LightSqColor=0xe7cf93;
   DarkSqColor=0x9e8661;
 
-  AntialiasPieces=1;
+  AntialiasPieces=0;
   ShowRating=1;
 
   VectorPieces=0;
@@ -115,6 +116,8 @@ Global::Global() {
   ChannelsToConsoleToo=0;
 
   ShowQuickbar=1;
+  LowTimeWarningLimit=5;
+  RetrieveChannelNames=1;
 
   sndevents[1].Pitch=650;
   sndevents[1].Duration=350;
@@ -126,6 +129,9 @@ Global::Global() {
   sndevents[3].Duration=40;
   sndevents[3].Count=3;
 
+  sndevents[4].Pitch=740;
+  sndevents[4].Duration=120;
+
   strcpy(ClockFont,DEFAULT_FONT_CLOK);
   strcpy(PlayerFont,DEFAULT_FONT_PLYR);
   strcpy(InfoFont,DEFAULT_FONT_INFO);
@@ -170,6 +176,8 @@ Global::Global() {
   RCKeys.push_back("DesktopStateDC");  //36
   RCKeys.push_back("ShowQuickbar");
   RCKeys.push_back("QuickbarButton");  //38
+  RCKeys.push_back("LowTimeWarningLimit");
+  RCKeys.push_back("RetrieveChannelNames"); //40
 
   PopupHelp = false;
 }
@@ -339,7 +347,7 @@ void Global::readRC() {
     // sound events
     if (!strcmp(p,RCKeys[17])) {
       i=atoi(t.token(sep));
-      if (i<4)
+      if (i < N_SOUND_EVENTS )
 	sndevents[i].read(t);
       continue;
     }
@@ -376,6 +384,8 @@ void Global::readRC() {
       qb->command=t.token("\n\r\t:");
       QuickbarButtons.push_back(qb);
     }
+    if (!strcmp(p,RCKeys[39])) { LowTimeWarningLimit=atoi(t.token(sep)); continue; }
+    if (!strcmp(p,RCKeys[40])) { RetrieveChannelNames=atoi(t.token(sep)); continue; }
 
   }
   fclose(f);  
@@ -417,7 +427,7 @@ void Global::writeRC() {
   fprintf(f,"%s::%d\n",RCKeys[15],FicsAutoLogin);
   fprintf(f,"%s::%d\n",RCKeys[16],BeepWhenOppMoves);
 
-  for(i=0;i<4;i++)
+  for(i=0;i< N_SOUND_EVENTS;i++)
     sndevents[i].write(f,RCKeys[17],i);
 
   fprintf(f,"%s::%d\n",RCKeys[18],EnableSounds);
@@ -446,6 +456,8 @@ void Global::writeRC() {
 	    QuickbarButtons[i]->icon,
 	    QuickbarButtons[i]->caption.c_str(),
 	    QuickbarButtons[i]->command.c_str());
+  fprintf(f,"%s::%d\n",RCKeys[39],LowTimeWarningLimit);
+  fprintf(f,"%s::%d\n",RCKeys[40],RetrieveChannelNames);
 
   fclose(f);
 }
@@ -554,6 +566,11 @@ void Global::challenged() {
     sndevents[3].safePlay();
 }
 
+void Global::timeRunningOut() {
+  if (EnableSounds)
+    sndevents[4].safePlay();
+}
+
 void Global::repaintAllBoards() {
   for(BLi=BoardList.begin();BLi!=BoardList.end();BLi++)
     (*BLi)->refreshPieceSet();
@@ -746,6 +763,100 @@ int HostBookmark::operator==(HostBookmark *hbm) {
 
 // -------------------------------- channel splitting
 
+IcsChannel::IcsChannel(char *s) {
+  TString t(512);
+  t.set(s);
+  number = atoi( t.token("\t\r\n") );
+  name = t.token("\t\r\n");
+}
+
+void ChannelSplitter::getChannels(char *ipaddr) {
+  char destname[512], url[512];
+  struct stat age;
+  time_t now, d;
+  pid_t kid;
+
+  global.debug("ChannelSplitter","getChannels",ipaddr);
+  channels.clear();
+
+  if (! global.RetrieveChannelNames)
+    return;
+
+  sprintf(destname,"/tmp/eboard-chlist-%s-%d.tmp", ipaddr, getuid() );
+  chlist=destname;
+
+  if (stat(destname, &age)==0) {
+    now=time(0);
+    d = now - age.st_mtime;
+    // list expires after 8 hours
+    if (d < 28800)
+      goto cs_gc_use_current;
+  }
+
+  sprintf(url,"http://eboard.sourceforge.net/ics/%s.txt",ipaddr);
+
+  kid=fork();
+  if (kid==0) {
+
+    execlp("wget","wget","-q","-O",destname,url,0);
+    exit(0);
+
+  } else {
+
+    global.zombies.add(kid, this);
+
+  }
+
+ cs_gc_use_current:
+  parseChannelList();
+    
+}
+
+void ChannelSplitter::ZombieNotification(int pid) {
+  parseChannelList();
+}
+
+void ChannelSplitter::parseChannelList() {
+  FILE *f;
+  char s[512];
+
+  global.debug("ChannelSplitter","parseChannelList");
+  channels.clear();
+
+  f=fopen( chlist.c_str(), "r" );
+  if (!f) {
+    global.debug("ChannelSplitter","parseChannelList","can't read file");
+    return;
+  }
+
+  if (fgets(s,511,f) != 0) {
+
+    if (strstr(s,"text/ics-channel-list")) {    
+      while( fgets(s,511,f) != 0) {
+	if (!isdigit(s[0])) break;
+	channels.push_back( IcsChannel(s) );
+      }
+    }
+
+  }
+
+  fclose(f);
+}
+
+const char * ChannelSplitter::getChannelTitle(int n) {
+  int i,j;
+  static char z[128];
+  j=channels.size();
+  for(i=0;i<j;i++) {
+    if (n==channels[i].number) {
+      sprintf(z,"#%d: %s",n,channels[i].name.c_str());
+      return z;
+    }
+  }
+  sprintf(z,"#%d",n);
+  return z;
+}
+
 void ChannelSplitter::ensurePane(int ch) {
   int i,j;
   j=panes.size();
@@ -762,9 +873,11 @@ void ChannelSplitter::createPane(int ch) {
   nb=getNotebook();
   if (!nb) return;  
   op=new Text();
-  sprintf(z,"Channel %d",ch);
+  
+  sprintf(z,"%s",getChannelTitle(ch) );
+
   op->show();
-  nb->addPage(op->widget,z,-200-ch);
+  nb->addPage(op->widget,z,-200-ch,true);
   op->setNotebook(nb,-200-ch);
   numbers.push_back(ch);
   panes.push_back(op);
@@ -782,6 +895,25 @@ void ChannelSplitter::appendToChannel(int ch,char *msg,int color,Importance im=I
     }  
 }
 
+void ChannelSplitter::removeRemovablePage(int n) {
+  int rn;
+  int i,j;
+  Notebook *nb;
+  
+  rn= -n;
+  rn-=200;
+  nb=getNotebook();
+
+  j=panes.size();
+  for(i=0;i<j;i++)
+    if (numbers[i]==rn) {
+      nb->removePage(n);
+      delete panes[i];
+      panes.erase(panes.begin() + i);
+      numbers.erase(numbers.begin() + i);
+    }
+}
+
 void ChannelSplitter::updateChannelScrollBacks() {
   int i,j;
   j=panes.size();
