@@ -1,10 +1,10 @@
-/* $Id: main.cc,v 1.10 2001/10/24 11:10:22 bergo Exp $ */
+/* $Id: main.cc,v 1.11 2002/02/13 03:53:56 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,7 @@
 #include "mainwindow.h"
 #include "global.h"
 #include "sound.h"
+#include "help.h"
 
 static void dump_tables(int signum) {
   // dump all internal tables to stderr when SIGUSR1 is received
@@ -80,6 +81,9 @@ int main(int argc,char **argv) {
   z->show();
   z->restoreDesk();
 
+  if (global.PopupHelp)
+    (new Help::GettingStarted())->show();
+
   gtk_main();
   
   for(zomb=global.TheOffspring.begin();zomb!=global.TheOffspring.end();
