@@ -1,4 +1,4 @@
-/* $Id: mainwindow.cc,v 1.81 2002/03/17 04:53:36 bergo Exp $ */
+/* $Id: mainwindow.cc,v 1.83 2002/04/07 04:49:21 bergo Exp $ */
 
 /*
 
@@ -195,6 +195,9 @@ MainWindow::MainWindow() {
   notebook->show();
   gtk_box_pack_start (GTK_BOX (v), notebook->widget, TRUE, TRUE, 0);
 
+  icsout=new TextSet();
+  global.outputset=icsout;
+
   tmp=new Board(true);
   notebook->addPage(tmp->widget,"Main Board",-1);
   tmp->setNotebook(notebook,-1);
@@ -207,7 +210,6 @@ MainWindow::MainWindow() {
   if (!global.ShowQuickbar)
     hideQuickbar();
 
-  icsout=new TextSet();
   inconsole=new Text();
   icsout->addTarget(inconsole);
   inconsole->show();
@@ -913,6 +915,7 @@ void MainWindow::cloneOnScratch(ChessGame *cg0) {
   cg=new ChessGame(cg0);
   cg->GameNumber = id;
   cg->LocalEdit = true;
+  cg->source = GS_Other;
 
   global.appendGame(cg,false);
   b=new EditBoard(cg);
