@@ -1,10 +1,10 @@
-/* $Id: mainwindow.h,v 1.46 2001/10/01 01:56:04 bergo Exp $ */
+/* $Id: mainwindow.h,v 1.51 2002/03/17 04:53:36 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -43,6 +43,7 @@
 #include "dlg_prefs.h"
 #include "help.h"
 #include "promote.h"
+#include "quickbar.h"
 #include "script.h"
 #include "stl.h"
 
@@ -63,7 +64,9 @@ class MainWindow : public WidgetProxy,
                    public StockListListener,
 		   public AdListListener,
                    public ConsoleListener,
-                   public PaneChangeListener
+                   public PaneChangeListener,
+		   public BookmarkListener,
+		   public UpdateInterface
 {
  public:
   MainWindow();
@@ -87,6 +90,8 @@ class MainWindow : public WidgetProxy,
 
   static GdkWindow *RefWindow;
 
+  void update();
+
  private:
   int HideMode; // password
   GtkItemFactory  *gif;
@@ -98,6 +103,7 @@ class MainWindow : public WidgetProxy,
   Text            *inconsole;
   Status          *status;
   PromotionPicker *promote;
+  QuickBar        *quickbar;
 
   GameListDialog  *gamelist;
   StockListDialog *stocklist;
@@ -105,9 +111,11 @@ class MainWindow : public WidgetProxy,
   ScriptList      *scriptlist;
   DetachedConsole *consolecopy;
 
+  bool QuickbarVisible;
+
   GtkTooltips *tooltips;
-  GtkWidget *navbar[7];
-  bool nav_enable[7];
+  GtkWidget *navbar[8];
+  bool nav_enable[8];
 
   GtkWidget *picseal;
   GdkPixmap *sealmap[2];
@@ -123,6 +131,7 @@ class MainWindow : public WidgetProxy,
 
   void setTitle(char *msg);
   void searchThemes();
+  void updateBookmarks();
   void parseThemeFile(char *name);
   void greet();
 
@@ -144,10 +153,16 @@ class MainWindow : public WidgetProxy,
   void saveDesk();
   void saveBuffer();
 
+  void newScratchBoard(bool clearboard);
+  void cloneOnScratch(ChessGame *cg0);
+
   int hook_count;
   void decrementHook();
   void incrementHook();
 
+  void showQuickbar();
+  void hideQuickbar();
+
   list<ThemeEntry *> Themes;
 
   friend void mainwindow_themeitem(GtkMenuItem *menuitem, gpointer data);
@@ -166,19 +181,27 @@ class MainWindow : public WidgetProxy,
   friend void     peer_connect_sjeng(gpointer data);
   friend void     peer_connect_crafty(gpointer data);
 
+  friend void     peer_scratch_empty(gpointer data);
+  friend void     peer_scratch_initial(gpointer data);
+
   friend void     peer_connect_ask(gpointer data);
   friend void     peer_disconnect(gpointer data);
   friend void     help_about(gpointer data);
   friend void     help_keys(gpointer data);
+  friend void     help_debug(gpointer data);
+  friend void     help_starting(gpointer data);
   friend gboolean mainwindow_idle_hook(gpointer data);
   friend void     mainwindow_icsout_changed(GtkEditable *gtke, gpointer data);
 
+  friend void     mainwindow_connect_bookmark(GtkWidget *w, gpointer data);
+
   friend void     navbar_back_all(GtkWidget *w,gpointer data);
   friend void     navbar_back_1(GtkWidget *w,gpointer data);
   friend void     navbar_forward_1(GtkWidget *w,gpointer data);
   friend void     navbar_forward_all(GtkWidget *w,gpointer data);
   friend void     navbar_movelist(GtkWidget *w,gpointer data);
   friend void     navbar_trash(GtkWidget *w,gpointer data);
+  friend void     navbar_toscratch(GtkWidget *w,gpointer data);
   friend void     navbar_flip(GtkWidget *w,gpointer data);
 
   friend void     sett_hilite(GtkWidget *w,gpointer data);
