@@ -1,4 +1,4 @@
-/* $Id: network.cc,v 1.28 2002/03/12 02:03:23 bergo Exp $ */
+/* $Id: network.cc,v 1.29 2002/04/07 22:14:11 bergo Exp $ */
 
 /*
 
@@ -567,6 +567,10 @@ int PipeConnection::open() {
   }
   if (!Quiet)
     global.status->setText(z);
+
+  if (opmode==1)
+    global.getChannels(HostAddress);
+
   return 0;
 }
 
