@@ -1,4 +1,4 @@
-/* $Id: network.h,v 1.12 2001/06/18 16:41:22 bergo Exp $ */
+/* $Id: network.h,v 1.13 2002/02/10 13:43:40 bergo Exp $ */
 
 /*
 
@@ -59,11 +59,12 @@ class Parent {
   int pid;
 };
 
-class PidRing {
+class PidRing : public SigChildHandler {
  public:
   void add(PidIssuer *po, int pid);
   void remove(PidIssuer *po);
   void funeral(int pid);
+  virtual void ZombieNotification(int pid);
  private:
   list<Parent *> parents;
 };
