@@ -1,10 +1,10 @@
-/* $Id: pieces.cc,v 1.17 2001/10/14 17:36:26 bergo Exp $ */
+/* $Id: pieces.cc,v 1.19 2002/03/17 04:53:36 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -306,12 +306,10 @@ void PieceSet::scale(int newside) {
   isrc=ni;
   calcAlphaMask();
 
-  if (global.AntialiasPieces) {
-    if (side > 35) {
-      antialias_b();
-      antialias_c();
-    }
-  }
+  if (global.AntialiasPieces)
+    if (side > 35)
+      antialias_a();
+
   buildCache();
 }
 
@@ -671,127 +669,46 @@ int PieceSet::alpha(int x,int y) {
 void PieceSet::antialias_a() {
   int i,j,k,m;
   int w,h;
-  int v[4],ea[4],df[4],adf[4],mi;
+  int d0,d1,d2,e;
 
-  w=isrc->rgb_width-1;
-  h=isrc->rgb_height-1;
+  static int gaussian[3][3]={ {1,2,1}, {2,4,2}, {1,2,1} };
+  int weight;
+  rgbptr dest;
 
-  for(j=0;j<h;j++)
-    for(i=0;i<w;i++) {
-      if (alpha(i,j) || alpha(i+1,j) || alpha(i,j+1) || alpha(i+1,j+1) ) {
-	++i;
-	continue;
-      }
-
-      v[0]=getPixel(i,j);
-      v[1]=getPixel(i+1,j);
-      v[2]=getPixel(i,j+1);
-      v[3]=getPixel(i+1,j+1);
-      
-      for(k=0;k<4;k++)
-	v[k]=RGB2YCbCr(v[k]);
-
-      // calc exclusive avg (ea);
-      for(k=0;k<4;k++) {
-	ea[k]=0;
-	for(m=0;m<4;m++) {
-	  if (m==k)
-	    continue;
-	  ea[k]+=pixr(v[m]);
-	}
-	ea[k]/=3;
-	df[k]=ea[k]-pixr(v[k]);
-	adf[k]=abs(df[k]);
-      }
-      
-      mi=0;
-      for(k=0;k<4;k++)
-	if (adf[k]>adf[mi])
-	  mi=k;
-
-      if (adf[mi] < 8)
-	continue;
-      
-      v[mi]=pixel( (3*pixr(v[mi]) + ea[mi])/4, pixg(v[mi]), pixb(v[mi]) );
-      v[mi]=YCbCr2RGB(v[mi]);
-      setPixel(i+(mi%2),j+(mi/2),v[mi]);            
-    }
-}
-
-void PieceSet::antialias_b() {
-  int i,j,sz;
-  int w,h;
-  int v[2],n[2],adf;
-  rgbptr imgclone;
-
-  w=(isrc->rgb_width*6)/7-1;
+  w=isrc->rgb_width;
   h=isrc->rgb_height;
 
-  imgclone=(rgbptr)g_malloc(sz=isrc->rgb_width*isrc->rgb_height*3);
-  memcpy(imgclone,isrc->rgb_data,sz);
+  dest=(rgbptr) malloc(3*w*h);
 
-  for(j=0;j<h;j++)
-    for(i=0;i<w;i++) {
-      if (alpha(i,j) || alpha(i+1,j) ) {
-	++i;
-	continue;
-      }
+  for(j=1;j<h-1;j++)
+    for(i=1;i<w-1;i++) {
+      if (alpha(i,j)) continue;
 
-      v[0]=RGB2YCbCr(getPixel(i,j));
-      v[1]=RGB2YCbCr(getPixel(i+1,j));
+      weight=0;
+      d0=0;
+      d1=0;
+      d2=0;
+      for(k=0;k<3;k++)
+	for(m=0;m<3;m++) {
+	  if (!alpha(i+m-1,j+k-1)) {
+	    weight+=gaussian[m][k];
+	    e = getPixel(i+m-1, j+k-1);
+	    d0 += gaussian[m][k] * pixr(e);
+	    d1 += gaussian[m][k] * pixg(e);
+	    d2 += gaussian[m][k] * pixb(e);
+	  }
+	}
       
-      adf=abs(pixr(v[0])-pixr(v[1]));
-      
-      if (adf < 144)
-	continue;
-
-      n[0]=pixel( (5*pixr(v[0]) + pixr(v[1]))/6, pixg(v[0]), pixb(v[0]) );
-      n[1]=pixel( (5*pixr(v[1]) + pixr(v[0]))/6, pixg(v[1]), pixb(v[1]) );
-      v[0]=YCbCr2RGB(n[0]);
-      v[1]=YCbCr2RGB(n[1]);
-      xSetPixel(imgclone,i,j,v[0]);
-      xSetPixel(imgclone,i+1,j,v[1]);
+      if (d0<0) d0=0;
+      if (d1<0) d1=0;
+      if (d2<0) d2=0;
+      if (weight==0) weight=1;
+      e= pixel ( d0/weight, d1/weight, d2/weight );
+      xSetPixel(dest, i, j, e);
     }
 
-  memcpy(isrc->rgb_data,imgclone,sz);
-  g_free(imgclone);
-}
-
-void PieceSet::antialias_c() {
-  int i,j,sz;
-  int w,h;
-  int v[2],n[2],adf;
-  rgbptr imgclone;
-
-  w=(isrc->rgb_width*6)/7;
-  h=isrc->rgb_height-1;
-
-  imgclone=(rgbptr)g_malloc(sz=isrc->rgb_width*isrc->rgb_height*3);
-  memcpy(imgclone,isrc->rgb_data,sz);
-
-  for(j=0;j<h;j++)
-    for(i=0;i<w;i++) {
-      if (alpha(i,j) || alpha(i,j+1) )
-	continue;
-
-      v[0]=RGB2YCbCr(getPixel(i,j));
-      v[1]=RGB2YCbCr(getPixel(i,j+1));
-
-      adf=abs(pixr(v[0])-pixr(v[1]));
-      
-      if (adf < 144)
-	continue;
-
-      n[0]=pixel( (5*pixr(v[0]) + pixr(v[1]))/6, pixg(v[0]), pixb(v[0]) );
-      n[1]=pixel( (5*pixr(v[1]) + pixr(v[0]))/6, pixg(v[1]), pixb(v[1]) );
-      v[0]=YCbCr2RGB(n[0]);
-      v[1]=YCbCr2RGB(n[1]);
-      xSetPixel(imgclone,i,j,v[0]);
-      xSetPixel(imgclone,i,j+1,v[1]);
-    }
-
-  memcpy(isrc->rgb_data,imgclone,sz);
-  g_free(imgclone);
+  memcpy(isrc->rgb_data, dest, 3*w*h);
+  free(dest);
 }
 
 void PieceSet::queueRequest(PReq *r) {
