@@ -1,4 +1,4 @@
-/* $Id: pieces.h,v 1.13 2001/10/14 17:36:26 bergo Exp $ */
+/* $Id: pieces.h,v 1.14 2002/03/17 04:53:36 bergo Exp $ */
 
 /*
 
@@ -101,8 +101,6 @@ class PieceSet {
 
   void prescale(int pixto,int pixfrom);
   void antialias_a();
-  void antialias_b();
-  void antialias_c();
 
   int  getPixel(int x,int y);
   void setPixel(int x,int y,int v);
