@@ -1,4 +1,4 @@
-/* $Id: proto_fics.cc,v 1.67 2002/03/17 20:51:47 bergo Exp $ */
+/* $Id: proto_fics.cc,v 1.69 2002/03/29 14:27:25 bergo Exp $ */
 
 /*
 
@@ -573,6 +573,7 @@ void FicsProtocolParser::createExaminedGame(int gameid,char *whitep,char *blackp
   cg->clock_regressive=1;
   cg->GameNumber=gameid;
   cg->StopClock=1;
+  cg->source = GS_ICS;
   strncpy(cg->PlayerName[0],whitep,64);
   strncpy(cg->PlayerName[1],blackp,64);
   cg->MyColor=WHITE|BLACK;
@@ -615,6 +616,7 @@ void FicsProtocolParser::createScratchPos(int gameid,char *whitep,char *blackp)
   cg->clock_regressive=1;
   cg->GameNumber=gameid;
   cg->StopClock=1;
+  cg->source=GS_ICS;
   strncpy(cg->PlayerName[0],whitep,64);
   strncpy(cg->PlayerName[1],blackp,64);
   cg->MyColor=WHITE|BLACK;
@@ -643,6 +645,7 @@ void FicsProtocolParser::createGame(ExtPatternMatcher &pm) {
 
   cg=new ChessGame();
 
+  cg->source=GS_ICS;
   cg->clock_regressive=1;
   cg->GameNumber=atoi(pm.getNToken(0));
   strncpy(cg->PlayerName[0],pm.getSToken(0),64);
@@ -722,6 +725,7 @@ void FicsProtocolParser::addGame(ExtPatternMatcher &pm) {
   cg->Inc=999;
   cg->Rated=0;
   cg->Variant=REGULAR;
+  cg->source = GS_ICS;
 
   global.prependGame(cg);
   b=new Board();
@@ -1014,20 +1018,24 @@ void FicsProtocolParser::parseStyle12(char *data) {
   case  0: // observed
   case -2: // observing examined game
     refgame->protodata[0]=257;
+    refgame->AmPlaying=false;
     break;
   case 1:
   case -1:
     refgame->protodata[0]=0;
     refgame->MyColor=(flip)?BLACK:WHITE;
+    refgame->AmPlaying=true;
     if ((global.IcsSeekGraph)&&(global.skgraph))
       global.skgraph->clear();
     break;
   case 2: // examiner mode
     refgame->protodata[0]=258;
     refgame->setFree();
+    refgame->AmPlaying=false;
     break;
   case -3: // isolated position
     refgame->protodata[0]=259;
+    refgame->AmPlaying=false;
     break;
   }
 
