@@ -1,4 +1,4 @@
-/* $Id: proto_fics.h,v 1.31 2001/10/13 00:22:10 bergo Exp $ */
+/* $Id: proto_fics.h,v 1.33 2002/03/17 20:51:47 bergo Exp $ */
 
 /*
 
@@ -96,6 +96,7 @@ class FicsProtocolParser : public ProtocolParser {
   void doGameAction(int gameid, int id);
 
   int AuthenticationGone;
+  bool LectureBotSpecial;
 
   PatternBinder Binder;
 
@@ -152,6 +153,10 @@ class FicsProtocolParser : public ProtocolParser {
   ExtPatternMatcher ChannelTell;
   ExtPatternMatcher Seek;
   ExtPatternMatcher Notify;
+  ExtPatternMatcher Challenge;
+
+  ExtPatternMatcher LectureBotXTell;
+  ExtPatternMatcher LectureBotXTellContinued;
 
   ExtPatternMatcher PTell;
 
