@@ -1,4 +1,4 @@
-/* $Id: text.h,v 1.17 2001/09/20 22:35:23 bergo Exp $ */
+/* $Id: text.h,v 1.19 2001/10/01 01:56:04 bergo Exp $ */
 
 /*
 
@@ -46,6 +46,13 @@ class OutputPane {
   virtual void setBackground(int color)=0;
 };
 
+class Searchable {
+ public:
+  Searchable();
+  virtual void execSearch()=0;
+  char SearchString[128];
+};
+
 class TextFilter {
  public:
   TextFilter();
@@ -65,7 +72,8 @@ class TextFilter {
 
 class Text : public WidgetProxy,
              public NotebookInsider,
-             public OutputPane {
+             public OutputPane,
+             public Searchable {
  public:
   Text();
   ~Text();
@@ -84,6 +92,12 @@ class Text : public WidgetProxy,
   void updateFont();
 
   void setBackground(int color);
+  void saveBuffer();
+
+  void findText();
+  void findTextNext();
+
+  void execSearch();
 
   TextFilter Filter;
   int ScrollBack;
@@ -94,6 +108,8 @@ class Text : public WidgetProxy,
   GtkWidget *text, *sbar;
   GtkStyle *style;
   int linecount;
+
+  int LastMatch;
 };
 
 class TextSet : public OutputPane {
@@ -166,4 +182,16 @@ class TextFilterDialog : public ModalDialog {
   friend void tfd_ok(GtkWidget *w, gpointer data);
 };
 
+class SearchTextDialog : public ModalDialog {
+ public:
+
+  SearchTextDialog(Searchable *src);
+
+ private:
+  GtkWidget *text;
+  Searchable *searchable;
+
+  friend void std_ok(GtkWidget *w, gpointer data);
+};
+
 #endif
