@@ -1,10 +1,10 @@
-/* $Id: widgetproxy.cc,v 1.11 2001/10/01 01:56:04 bergo Exp $ */
+/* $Id: widgetproxy.cc,v 1.16 2002/03/17 04:53:36 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,10 @@ void WidgetProxy::show() {
   gtk_widget_show(widget);
 }
 
+void WidgetProxy::hide() {
+  gtk_widget_hide(widget);
+}
+
 void WidgetProxy::repaint() {
   gtk_widget_queue_resize(widget);
 }
@@ -52,7 +56,7 @@ void WidgetProxy::setIcon(char **xpmdata,const char *text) {
                                        &style->bg[GTK_STATE_NORMAL],
                                        (gchar **) xpmdata);
   gdk_window_set_icon (widget->window, NULL, icon, mask);
-  gdk_window_set_icon_name(widget->window,text);
+  gdk_window_set_icon_name(widget->window,(gchar *)text);
 }
 
 void WidgetProxy::restorePosition(WindowGeometry *wg) {
@@ -62,6 +66,32 @@ void WidgetProxy::restorePosition(WindowGeometry *wg) {
   gdk_window_move_resize(widget->window,wg->X,wg->Y,wg->W,wg->H);
 }
 
+GtkWidget * WidgetProxy::PixButton(char **xpmicon, char *caption) {
+  GdkPixmap *d;
+  GdkBitmap *mask;
+  GtkWidget *b, *p, *v, *t;
+  GtkStyle *style;
+
+  b=gtk_button_new();
+  v=gtk_vbox_new(FALSE,1);
+  gtk_container_set_border_width(GTK_CONTAINER(v),2);
+  gtk_container_add(GTK_CONTAINER(b),v);
+
+  style=gtk_widget_get_style(widget);
+  d = gdk_pixmap_create_from_xpm_d (widget->window, &mask,
+				    &style->bg[GTK_STATE_NORMAL],
+				    (gchar **) xpmicon);
+  p=gtk_pixmap_new(d, mask);
+  gtk_box_pack_start(GTK_BOX(v),p,FALSE,TRUE,0);
+  t=gtk_label_new(caption);
+  gtk_box_pack_start(GTK_BOX(v),t,FALSE,TRUE,0);
+
+  gtk_widget_show(t);
+  gtk_widget_show(p);
+  gtk_widget_show(v);
+  return b;
+}
+
 // ------------
 
 BoxedLabel::BoxedLabel(char *text) {
@@ -119,6 +149,26 @@ void modal_release(GtkWidget *w,gpointer data) {
   me->release();
 }
 
+// -- non modal
+
+NonModalDialog::NonModalDialog(char *title) : ModalDialog(title) {
+
+}
+
+NonModalDialog::~NonModalDialog() {
+
+}
+
+void NonModalDialog::show() {
+  gtk_widget_show(widget);
+  if (focused_widget)
+    gtk_widget_grab_focus(focused_widget);
+}
+
+void NonModalDialog::releaseWithoutDelete() {
+  gtk_widget_destroy(widget);  
+}
+
 // ------------ progress
 gint upw_delete (GtkWidget * widget, GdkEvent * event, gpointer data);
 
@@ -430,3 +480,114 @@ void filedlg_destroy (GtkWidget * w, gpointer data) {
   fd->destroyed=true;
   fd->gotresult=true;
 }
+
+// ----------- layout box for the clock (previous code was getting out of hand)
+
+LayoutBox::LayoutBox() {
+  GC=0;
+  Target=0;
+  X=Y=W=H=0;
+}
+
+void LayoutBox::prepare(GdkPixmap *t, GdkGC *gc, int a, int b, int c, int d) {
+  int i;
+  Target = t;
+  GC = gc;
+  X=a; Y=b, W=c; H=d;
+
+  for(i=0;i<5;i++)
+    fontv[i]=0;
+}
+
+void LayoutBox::setFont(int i,GdkFont *f) {
+  fontv[i%5] = f;
+}
+
+void LayoutBox::setColor(int c) {
+  gdk_rgb_gc_set_foreground(GC,c);
+}
+
+void LayoutBox::drawRect(int x,int y,int w,int h,bool fill) {
+  gdk_draw_rectangle(Target,GC,fill?TRUE:FALSE,x,y,w,h);
+}
+
+void LayoutBox::drawLine(int x,int y,int w,int h) {
+  gdk_draw_line(Target,GC,x,y,w,h);
+}
+
+void LayoutBox::consumeTop(int v) { Y+=v; H-=v; }
+void LayoutBox::consumeBottom(int v) { H-=v; }
+
+void LayoutBox::drawString(int x,int y, int f, char *s) {
+  gdk_draw_string(Target,fontv[f],GC,x,y,s);
+}
+
+void LayoutBox::drawSubstring(int x,int y, int f, char *s,int len) {
+  gdk_draw_text(Target,fontv[f],GC,x,y,s,len);
+}
+
+int LayoutBox::stringWidth(int f,char *s) {
+  return(gdk_string_width(fontv[f],s));
+}
+
+int LayoutBox::substringWidth(int f,char *s,int len) {
+  return(gdk_text_width(fontv[f],s,len));
+}
+
+int LayoutBox::fontHeight(int f) {
+  return(gdk_string_height(fontv[f], "Aypb178XW@"));
+}
+
+bool LayoutBox::drawBoxedString(int x,int y,int w,int h,
+				int f,char *s,char *sep) 
+{
+  int cy, lskip;
+  char *first, *p, *last;
+
+  lskip = fontHeight(f) + 2;
+
+  // base case: string fits in one line
+  if (stringWidth(f,s) <= w) {
+    drawString(x,y,f,s);
+    return true;
+  }
+
+  y += lskip;
+  cy = y;
+  last = s + strlen(s) - 1;
+  first = s;
+
+  while( *first == ' ' ) ++first;
+  while(first < last) {
+
+    if ( (cy+lskip) > (y+h) )
+      return false;
+
+    for(p=last;p!=first;p--) {
+      if (!strchr(sep,*p)) continue;
+      if (substringWidth(f,first,p-first+1) <= w) {
+	drawSubstring(x,cy,f,first,p-first+1);
+	first = p+1;
+	cy += lskip;
+	break;
+      } // if substring...
+    } // for
+
+    // couldn't fit line, repeat the step but break anywhere :-(
+    if (p==first) {
+      for(p=last;p!=first;p--) {
+	if (substringWidth(f,first,p-first+1) <= w) {
+	  drawSubstring(x,cy,f,first,p-first+1);
+	  first = p+1;
+	  cy += lskip;
+	  break;
+	}
+      }
+    } // if p==first
+
+    while( *first == ' ' ) ++first;
+
+  } // while
+  return true;
+
+} // method
