@@ -1,10 +1,10 @@
-/* $Id: widgetproxy.h,v 1.11 2001/10/01 01:56:04 bergo Exp $ */
+/* $Id: widgetproxy.h,v 1.15 2002/03/17 04:53:36 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -36,11 +36,14 @@ class WidgetProxy {
   WidgetProxy();
 
   virtual void show();
+  virtual void hide();
   virtual void repaint();
 
   void setIcon(char **xpmdata,const char *text);
   void restorePosition(WindowGeometry *wg);
 
+  GtkWidget * PixButton(char **xpmicon, char *caption);
+
   GtkWidget *widget;
 };
 
@@ -58,16 +61,24 @@ class ModalDialog : public WidgetProxy {
   virtual ~ModalDialog();
   virtual void show();
 
- protected:
   void setDismiss(GtkObject *obj,char *sig);
   void release();
-  void releaseWithoutDelete();
+  virtual void releaseWithoutDelete();
 
   GtkWidget *focused_widget;
 
   friend void modal_release(GtkWidget *w,gpointer data);
 };
 
+class NonModalDialog : public ModalDialog {
+ public:
+  NonModalDialog(char *title);
+  ~NonModalDialog();
+  virtual void show();
+
+  virtual void releaseWithoutDelete();
+};
+
 class UnboundedProgressWindow : public WidgetProxy {
  public:
   UnboundedProgressWindow(const char *_templ);
@@ -137,4 +148,32 @@ class FileDialog : public WidgetProxy {
 
 };
 
+class LayoutBox {
+ public:
+  LayoutBox();
+
+  void prepare(GdkPixmap *t, GdkGC *gc, int a, int b, int c,int d);
+  void setFont(int i,GdkFont *f);
+
+  void setColor(int c);
+  void drawRect(int x,int y,int w,int h,bool fill);
+  void drawLine(int x,int y,int w,int h);
+  void drawString(int x,int y, int f, char *s);
+  void drawSubstring(int x,int y, int f, char *s,int len);
+  int  stringWidth(int f,char *s);
+  int  substringWidth(int f,char *s,int len);
+  int  fontHeight(int f);
+
+  bool drawBoxedString(int x,int y,int w,int h,int f,char *s,char *sep);
+
+  void consumeTop(int v);
+  void consumeBottom(int v);
+
+  int X,Y,W,H;
+  GdkFont * fontv[5];
+  GdkPixmap * Target;
+  GdkGC     * GC;
+  
+};
+
 #endif
